@@ -5,7 +5,7 @@ pub const ECHO_COMMAND: crate::Command = crate::Command {
   args: &[],
   description: "Echo back the arguments",
   handler: |ctx, args| {
-    crate::logger::create_logger_from_logger!(ctx.logger, true);
+    create_logger_from_logger!(ctx.logger, true);
 
     Box::pin(async move {
       log!(raw, args.join(" "));
