@@ -6,6 +6,8 @@ pub(crate) mod re_exports {
   #[cfg(feature = "std")]
   pub use std as alloc;
 
+  pub use crate::arg_parser::Arg;
+  pub use crate::logger::create_logger_from_logger;
   pub use alloc::{
     boxed::Box,
     collections::BTreeMap,
@@ -14,7 +16,12 @@ pub(crate) mod re_exports {
     sync::Arc,
     vec::Vec,
   };
-  pub use core::{future::Future, pin::Pin};
+  pub use core::{
+    fmt::{self, Display, Formatter, Result as FmtResult},
+    future::Future,
+    pin::Pin,
+  };
+  pub use itertools::Itertools;
 }
 
 use core::future::Future as Future_;
@@ -47,7 +54,7 @@ impl<'a> SeaShell<'a> {
     logger_: impl logger::Logger + 'a,
     unicode_supported: bool,
   ) -> Self {
-    logger::create_logger_from_logger!(logger_, true);
+    create_logger_from_logger!(logger_, true);
 
     log!(info, "Welcome to Sea Shell version: {}", VERSION);
     log!(info, DESCRIPTION);
@@ -62,33 +69,34 @@ impl<'a> SeaShell<'a> {
   }
 
   pub async fn handle_command(&mut self, input: impl AsRef<str>) {
-    let input_ = input.as_ref().trim();
+    let input = input.as_ref().trim();
 
-    if input_.is_empty() {
+    if input.is_empty() {
       return;
     }
 
-    let input = input_
-      .split_whitespace()
-      .filter_map(|input| {
-        let trimmed = input.trim();
+    let mut input_ = input.split_whitespace().filter_map(|input| {
+      let trimmed = input.trim();
 
-        if trimmed.is_empty() {
-          None
-        } else {
-          Some(trimmed.into())
-        }
-      })
-      .collect::<Vec<String>>();
+      if trimmed.is_empty() {
+        None
+      } else {
+        Some(trimmed.into())
+      }
+    });
 
-    self.state.history.push(input_.into());
+    let command = input_.next().unwrap();
 
-    logger::create_logger_from_logger!(self.logger, true);
-    let code = match self.get_command(&input[0]) {
-      Some(command) => {
-        log!(debug, "executing: {}...", input[0]);
+    let args = input_.collect::<Vec<_>>();
 
-        let out = (command.handler)(self.clone(), input.into_iter().skip(1).collect()).await;
+    self.state.history.push(input.into());
+
+    create_logger_from_logger!(self.logger, true);
+    let code = match self.get_command(&command) {
+      Some(command_) => {
+        log!(debug, "executing: {}...", command);
+
+        let out = (command_.handler)(self.clone(), args).await;
 
         if let Some(self_) = out.0 {
           *self = self_;
@@ -97,7 +105,7 @@ impl<'a> SeaShell<'a> {
         out.1
       }
       None => {
-        log!(error, "command not found: {}", input[0]);
+        log!(error, "command not found: {}", command);
 
         1
       }
@@ -119,9 +127,30 @@ impl<'a> SeaShell<'a> {
 pub struct Command {
   pub name: &'static str,
   pub description: &'static str,
-  pub args: &'static [arg_parser::Arg<'static>],
+  pub args: &'static [Arg<'static>],
   #[allow(clippy::type_complexity)]
   pub handler: for<'a> fn(SeaShell<'a>, Vec<String>) -> Future<'a, (Option<SeaShell<'a>>, i32)>,
 }
 
+impl Display for Command {
+  fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
+    let mut help_text = String::new();
+
+    help_text.push_str(self.name);
+
+    if !self.args.is_empty() {
+      help_text.push(' ');
+
+      for arg in self.args {
+        help_text.push_str(&format!("{}", arg));
+      }
+    }
+
+    help_text.push_str(": ");
+    help_text.push_str(self.description);
+
+    write!(f, "{}", help_text)
+  }
+}
+
 pub(crate) type Future<'a, T> = Pin<Box<dyn Future_<Output = T> + 'a>>;
